## Objective

The objective of the `depandabot` job is to provide a way to update the requirements.txt file and create a merge request on a Gitlab instance. This reusable job can help speed up other jobs creation and ensure consistent configuration across CI jobs.

## How to use it

1. Include the depandabot template in your CI/CD configuration (see quick use above).
2. Create a job that extend the `depandabot` job template.
3. If you need to customize the job, check
   the [jobs customization](https://docs.r2devops.io/get-started/use-templates/#job-templates-customization).

## Variables

| Name                     | Description                                                                                                                                                   | Default                                      |
| ------------------------ | ------------------------------------------------------------------------------------------------------------------------------------------------------------- | -------------------------------------------- |
| `PROJECT_PATH`           | The path to the project root directory.                                                                                                                       | `"."`                                        |
| `REQUIREMENTS_FILE_PATH` | the path to the requirements file.                                                                                                                            | `"${PROJECT_PATH}/requirements.txt"`         |
| `IMAGE_TAG`              | The default tag for the docker image. See [Python Docker Official Image](https://hub.docker.com/_/python) for supported tags and respective Dockerfile links. | `"latest"`                                   |
| `GITLAB_API_URL`           | The host name of the GitLab instance | `${CI_SERVER_HOST}` |

## Example of use

```yaml
include:
    # Include the python_install job template (don't forget to replace the version tag)
    - remote: 'https://api.r2devops.io/job/r/gitlab/dorianturba/r2devops_catalog/r2_metadata/depandabot@0.1.0.yaml'

requirements311:
    extends:
        - .depandabot  # extends the python_install job template
    stage: dependency_management
    variables:
        REQUIREMENTS_FILE_PATH: "${PROJECT_PATH}/requirements-py311.txt"  # override the default REQUIREMENTS_FILE_PATH variable
        IMAGE_TAG: "3.11" # override the default IMAGE_TAG variable
        GITLAB_API_URL: "gitlab.example.com" # override the default GITLAB_API_URL
    script:
        - !reference [script]  # reuse the script from the python_install job template
```
